BaseTool class abstract
- Implementers
Constructors
-
BaseTool({required String name, String? description, String? title, required Map<
String, dynamic> inputSchema, ToolContentSpec? inputSpec, ToolContentSpec? outputSpec, Map<String, dynamic> ? outputSchema, String? thumbnailUrl, Map<String, dynamic> ? defs, String? pricing, bool supportsContext = false})
Properties
-
defs
→ Map<
String, dynamic> ? -
final
- description → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
inputSchema
→ Map<
String, dynamic> -
final
- inputSpec → ToolContentSpec?
-
final
- name → String
-
final
-
outputSchema
→ Map<
String, dynamic> ? -
final
- outputSpec → ToolContentSpec?
-
final
- pricing → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- supportsContext → bool
-
final
- thumbnailUrl → String?
-
final
- title → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited