ContentTool class abstract
Constructors
-
ContentTool({required String name, String? description, String? title, required Map<
String, dynamic> inputSchema, ToolContentSpec? inputSpec, ToolContentSpec? outputSpec, Map<String, dynamic> ? outputSchema, String? thumbnailUrl, Map<String, dynamic> ? defs, String? pricing, bool supportsContext = false})
Properties
-
defs
→ Map<
String, dynamic> ? -
finalinherited
- description → String?
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
inputSchema
→ Map<
String, dynamic> -
finalinherited
- inputSpec → ToolContentSpec?
-
finalinherited
- name → String
-
finalinherited
-
outputSchema
→ Map<
String, dynamic> ? -
finalinherited
- outputSpec → ToolContentSpec?
-
finalinherited
- pricing → String?
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- supportsContext → bool
-
finalinherited
- thumbnailUrl → String?
-
finalinherited
- title → String?
-
finalinherited
Methods
-
execute(
ToolContext context, ToolInput input) → Future< ToolCallOutput> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited