ToolResponseSentListener class abstract interface

Receives a notification only after a non-streaming tool response has been handed back to the caller successfully.

Tools that refresh or replace the surface hosting them should use this boundary instead of starting that work from execute.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onToolResponseSent(ToolContext context, Content response) FutureOr<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited