AccessBindingsPage class

Constructors

AccessBindingsPage({required List<ProjectAccessGrant> accessGrants, String? continuationToken})
AccessBindingsPage.fromJson(Map<String, dynamic> json)
factory

Properties

accessGrants List<ProjectAccessGrant>
final
continuationToken String?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited