AccessResource class

Constructors

AccessResource({required String type, required String id, String? name, Map<String, dynamic>? metadata, Map<String, String>? annotations})
const
AccessResource.fromJson(Map<String, dynamic> json)
factory

Properties

annotations Map<String, String>?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
metadata Map<String, dynamic>?
final
name String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited