AccessSubject class

Constructors

AccessSubject({required String type, required String id, String? name, String? firstName, String? lastName, String? email, String? objectType, String? relation})
const
AccessSubject.fromJson(Map<String, dynamic> json)
factory

Properties

email String?
final
firstName String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
lastName String?
final
name String?
final
objectType String?
final
relation String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited