AccessTestResult class
Constructors
- AccessTestResult({required bool allowed, AccessResource? resource, AccessSubject? subject, String? relation})
-
const
-
AccessTestResult.fromJson(Map<
String, dynamic> json) -
factory
Properties
- allowed → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- relation → String?
-
final
- resource → AccessResource?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subject → AccessSubject?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited