AgentRoomGrant class

Inheritance

Constructors

AgentRoomGrant({LivekitGrant? livekit, QueuesGrant? queues, MessagingGrant? messaging, DatasetGrant? dataset, MemoryGrant? memory, SyncGrant? sync, StorageGrant? storage, ContainersGrant? containers, DeveloperGrant? developer, AgentsGrant? agents, LLMGrant? llm, AdminGrant? admin, SecretsGrant? secrets, TunnelsGrant? tunnels, ServicesGrant? services})
AgentRoomGrant.fromApiScope(ApiScope scope)
factory
AgentRoomGrant.fromJson(Map<String, dynamic> json)
factory

Properties

admin AdminGrant?
finalinherited
agents AgentsGrant?
finalinherited
containers ContainersGrant?
finalinherited
dataset DatasetGrant?
finalinherited
developer DeveloperGrant?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
livekit LivekitGrant?
finalinherited
llm LLMGrant?
finalinherited
memory MemoryGrant?
finalinherited
messaging MessagingGrant?
finalinherited
queues QueuesGrant?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secrets SecretsGrant?
finalinherited
services ServicesGrant?
finalinherited
storage StorageGrant?
finalinherited
sync SyncGrant?
finalinherited
tunnels TunnelsGrant?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited