Balance class

Constructors

Balance({required double balance, required double? autoRechargeAmount, required double? autoRechargeThreshhold, required DateTime? lastRecharge, required double? monthlyBudget, required bool autoRechargePaused, required double? autoRechargedThisMonth})

Properties

autoRechargeAmount double?
final
autoRechargedThisMonth double?
final
autoRechargePaused bool
final
autoRechargeThreshhold double?
final
balance double
final
hashCode int
The hash code for this object.
no setterinherited
lastRecharge DateTime?
final
monthlyBudget double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited