EffectiveAccess class
Constructors
-
EffectiveAccess({required AccessResource resource, required AccessSubject subject, required List<
String> effectiveRoles, required Map<String, bool> capabilities}) -
const
-
EffectiveAccess.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
capabilities
→ Map<
String, bool> -
final
-
effectiveRoles
→ List<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- resource → AccessResource
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subject → AccessSubject
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited