Feed class

Constructors

Feed({required String id, required String projectId, required DateTime createdAt, required String name, required String description, required String visibility, required bool paused, required Map<String, String> annotations, required Object? messageSchema})
Feed.fromJson(Map<String, dynamic> json)
factory

Properties

annotations Map<String, String>
final
createdAt DateTime
final
description String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
messageSchema Object?
final
name String
final
paused bool
final
projectId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
visibility String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited