Group class

Constructors

Group({required String id, required String name, String? displayName, String? email, Map<String, dynamic> metadata = const {}, Map<String, String> annotations = const {}})
const
Group.fromJson(Map<String, dynamic> json)
factory

Properties

annotations Map<String, String>
final
displayName String?
final
email String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
metadata Map<String, dynamic>
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited