GroupsPage class
Constructors
-
GroupsPage({required List<
Group> groups, String? continuationToken}) -
const
-
GroupsPage.fromJson(Map<
String, dynamic> json) -
factory
Properties
- continuationToken → String?
-
final
-
groups
→ List<
Group> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited