LlmLogger class

Constructors

LlmLogger({required String id, required String projectId, required String destinationFeedId, required String filterExpression, required bool paused, required DateTime createdAt, required Map<String, String> annotations})
LlmLogger.fromJson(Map<String, dynamic> json)
factory

Properties

annotations Map<String, String>
final
createdAt DateTime
final
destinationFeedId String
final
filterExpression String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
paused bool
final
projectId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited