LlmQuotaState class

Constructors

LlmQuotaState({required String projectId, required LlmQuotaSubjectType subjectType, required String subjectId, required double? monthlyQuota, required double? monthlyQuotaOverride, required double? balance, required double spent, required DateTime resetsAt, required bool enabled})
const
LlmQuotaState.fromJson(Map<String, dynamic> json)
factory

Properties

balance double?
final
enabled bool
final
hashCode int
The hash code for this object.
no setterinherited
monthlyQuota double?
final
monthlyQuotaOverride double?
final
projectId String
final
resetsAt DateTime
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spent double
final
subjectId String
final
subjectType LlmQuotaSubjectType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited