Mailbox class
Constructors
Properties
- address → String
-
final
-
annotations
→ Map<
String, String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- public → bool
-
final
- queue → String
-
final
- room → String
-
final
- roomId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited