ManagedSecret class

Inheritance

Constructors

ManagedSecret({required String id, required String type, required String name, String? delegatedTo, String? agentId, required String dataBase64})
ManagedSecret.fromJson(Map<String, dynamic> json)
factory

Properties

agentId String?
finalinherited
data Uint8List
no setter
dataBase64 String
final
delegatedTo String?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
id String
finalinherited
name String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited