MeshagentException class

A simple custom exception to denote HTTP errors.

Implemented types
Implementers

Constructors

MeshagentException(String message, {int? statusCode, String? errorCode, String? errorMessage})
MeshagentException.fromResponse(String message, Response response)
factory

Properties

displayMessage String
no setter
errorCode String?
final
errorMessage String?
final
hashCode int
The hash code for this object.
no setterinherited
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited