PersonalSession class

Constructors

PersonalSession({required String id, required String clientType, required DateTime createdAt, required DateTime lastAuthenticatedAt, required DateTime lastSeenAt, required DateTime expiresAt, required int oauthTokenCount, required int iapSessionCount, required bool current, String? clientName, String? operatingSystem, String? deviceClass, String? friendlyName, String? city, String? region, String? countryCode, DateTime? revokedAt})
const
PersonalSession.fromJson(Map<String, dynamic> json)
factory

Properties

city String?
final
clientName String?
final
clientType String
final
countryCode String?
final
createdAt DateTime
final
current bool
final
deviceClass String?
final
expiresAt DateTime
final
friendlyName String?
final
hashCode int
The hash code for this object.
no setterinherited
iapSessionCount int
final
id String
final
lastAuthenticatedAt DateTime
final
lastSeenAt DateTime
final
oauthTokenCount int
final
operatingSystem String?
final
region String?
final
revokedAt DateTime?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited