ProjectAccessGrant class
Constructors
-
ProjectAccessGrant({required AccessResource resource, required AccessSubject subject, List<
String> ? directRoles}) -
ProjectAccessGrant.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
directRoles
→ List<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- resource → AccessResource
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subject → AccessSubject
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited