ProjectAgentRoomGrant class
Constructors
- ProjectAgentRoomGrant({required ManagedAgent agent, required Room room, required AgentRoomGrant permissions})
-
ProjectAgentRoomGrant.fromJson(Map<
String, dynamic> json) -
factory
Properties
- agent → ManagedAgent
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- permissions → AgentRoomGrant
-
final
- room → Room
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited