ProjectMember class

Constructors

ProjectMember({required String id, required String email, String? firstName, String? lastName, List<String>? directRoles})
const
ProjectMember.fromJson(Map<String, dynamic> json)
factory

Properties

directRoles List<String>
final
email String
final
firstName String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
lastName String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited