ProjectRepository class

Constructors

ProjectRepository({required String id, required String projectId, required String name, required String description, required Map<String, String> annotations, required DateTime createdAt})
ProjectRepository.fromJson(Map<String, dynamic> json)
factory

Properties

annotations Map<String, String>
final
createdAt DateTime
final
description String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
name String
final
projectId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited