ProjectRepositoryImage class

Constructors

ProjectRepositoryImage({required String digest, required List<String> tags, String? mediaType, int? manifestSize, int? imageSize, DateTime? updatedAt})
ProjectRepositoryImage.fromJson(Map<String, dynamic> json)
factory

Properties

digest String
final
hashCode int
The hash code for this object.
no setterinherited
imageSize int?
final
manifestSize int?
final
mediaType String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List<String>
final
updatedAt DateTime?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited