ProjectRoleInfo class

Constructors

ProjectRoleInfo({required ProjectRole role, required bool canCreateRooms, required bool canCreateAgents, required bool canUseLlmProxy, required bool isAdmin, required bool isDeveloper})
ProjectRoleInfo.fromJson(Map<String, dynamic> json)
factory

Properties

canCreateAgents bool
final
canCreateRooms bool
final
canUseLlmProxy bool
final
hashCode int
The hash code for this object.
no setterinherited
isAdmin bool
final
isDeveloper bool
final
role ProjectRole
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited