RoomDisabledException class

Inheritance

Constructors

RoomDisabledException(String message, {int? statusCode, String? errorCode})

Properties

displayMessage String
no setterinherited
errorCode String?
finalinherited
errorMessage String?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited