RoomIapSession class

Constructors

RoomIapSession({required String id, required String userId, required String email, required String clientType, required DateTime createdAt, required DateTime lastSeenAt, required DateTime expiresAt, String? firstName, String? lastName, String? clientName, String? operatingSystem, String? deviceClass, String? friendlyName, String? city, String? region, String? countryCode, DateTime? revokedAt})
const
RoomIapSession.fromJson(Map<String, dynamic> json)
factory

Properties

city String?
final
clientName String?
final
clientType String
final
countryCode String?
final
createdAt DateTime
final
deviceClass String?
final
displayName String
no setter
email String
final
expiresAt DateTime
final
firstName String?
final
friendlyName String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
lastName String?
final
lastSeenAt DateTime
final
operatingSystem String?
final
region String?
final
revokedAt DateTime?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited