RoomSession class

Constructors

RoomSession({required String id, required String? roomId, required String roomName, required DateTime createdAt, required bool isActive, required Map<String, num>? participants, String kind = 'room', String? agentId, String? agentName})
RoomSession.fromJson(Map<String, dynamic> json)
factory

Properties

agentId String?
final
agentName String?
final
createdAt DateTime
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
isActive bool
final
kind String
final
participants Map<String, num>?
final
roomId String?
final
roomName String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited