Route class

Constructors

Route({required String domain, required RouteSpec spec})
Route.fromJson(Map<String, dynamic> json)
factory

Properties

agentName String
no setter
annotations Map<String, String>
no setter
domain String
final
hashCode int
The hash code for this object.
no setterinherited
port String
no setter
roomName String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spec RouteSpec
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited