RouteContentSpec class

Constructors

RouteContentSpec({String subpath = '', List<RouteCorsRule> cors = const [], bool index = false, bool iap = false, String compression = 'brotli'})
RouteContentSpec.fromJson(Map<String, dynamic> json)
factory

Properties

compression String
final
cors List<RouteCorsRule>
final
hashCode int
The hash code for this object.
no setterinherited
iap bool
final
index bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subpath String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited