ScheduledTaskRun class

Constructors

ScheduledTaskRun({required String id, required String taskId, required String projectId, required String roomId, required String roomName, String? queuedMessageId, required String target, required String status, String? error, String? containerId, required DateTime scheduledTime, DateTime? timeoutAt, DateTime? startedAt, DateTime? leaseExpiresAt, int attemptCount = 0, DateTime? completedAt})
ScheduledTaskRun.fromJson(Map<String, dynamic> json)
factory

Properties

attemptCount int
final
completedAt DateTime?
final
containerId String?
final
error String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
leaseExpiresAt DateTime?
final
projectId String
final
queuedMessageId String?
final
roomId String
final
roomName String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scheduledTime DateTime
final
startedAt DateTime?
final
status String
final
target String
final
taskId String
final
timeoutAt DateTime?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited