SecretProxyAccessGrant class

Constructors

SecretProxyAccessGrant({required AccessSubject subject, required List<String> roles})

Properties

hashCode int
The hash code for this object.
no setterinherited
roles List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subject AccessSubject
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) SecretProxyAccessGrant