SecretProxyAccessGrantsPage class

Constructors

SecretProxyAccessGrantsPage({required List<SecretProxyAccessGrant> accessGrants, String? continuationToken})

Properties

accessGrants List<SecretProxyAccessGrant>
final
continuationToken String?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) SecretProxyAccessGrantsPage