SecretVersion class

Constructors

SecretVersion({required String id, required String secretId, required int version, required String encryptionKeyId, String? valueSha256, String? createdByUserId, String? createdByServiceAccountId, required DateTime createdAt})

Properties

createdAt DateTime
final
createdByServiceAccountId String?
final
createdByUserId String?
final
encryptionKeyId String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secretId String
final
valueSha256 String?
final
version int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) SecretVersion