DatabaseClient class

Constructors

DatabaseClient({required RoomClient room})

Properties

hashCode int
The hash code for this object.
no setterinherited
room RoomClient
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addColumnsOfType({required String table, required Map<String, DataType> newColumns, List<String>? namespace, String? branch}) Future<void>
addColumnWithExpression({required String table, required Map<String, String> newColumns, List<String>? namespace, String? branch}) Future<void>
count({required String table, String? text, List<double>? vector, Object? where, List<String>? namespace, String? branch, int? version}) Future<int>
createBranch({required String branch, String? fromBranch, List<String>? namespace}) Future<void>
createFullTextSearchIndex({required String table, required String column, List<String>? namespace, String? branch, bool replace = false}) Future<void>
createScalarIndex({required String table, required String column, List<String>? namespace, String? branch, bool replace = false}) Future<void>
createTableFromData({required String name, required DatabaseRows data, CreateMode mode = CreateMode.create, List<String>? namespace, String? branch, Map<String, dynamic>? metadata}) Future<void>
createTableFromDataStream({required String name, required DatabaseRowChunks chunks, Map<String, DataType>? schema, CreateMode mode = CreateMode.create, List<String>? namespace, String? branch, Map<String, dynamic>? metadata}) Future<void>
createTableWithSchema({required String name, required Map<String, DataType> schema, CreateMode mode = CreateMode.create, List<String>? namespace, String? branch, Map<String, dynamic>? metadata}) Future<void>
createVectorIndex({required String table, required String column, List<String>? namespace, String? branch, bool replace = false}) Future<void>
delete({required String table, required String where, List<String>? namespace, String? branch}) Future<void>
deleteBranch({required String branch, List<String>? namespace}) Future<void>
dropColumns({required String table, required List<String> columns, List<String>? namespace, String? branch}) Future<void>
dropIndex({required String table, required String name, List<String>? namespace, String? branch}) Future<void>
dropTable({required String name, bool ignoreMissing = false, List<String>? namespace, String? branch}) Future<void>
insert({required String table, required DatabaseRows records, List<String>? namespace, String? branch}) Future<void>
insertStream({required String table, required DatabaseRowChunks chunks, List<String>? namespace, String? branch}) Future<void>
inspect(String table, {List<String>? namespace, String? branch, int? version}) Future<Map<String, DataType>>
listBranches({List<String>? namespace}) Future<List<TableBranch>>
listIndexes(String table, {List<String>? namespace, String? branch, int? version}) Future<List<TableIndex>>
listTables({List<String>? namespace, String? branch}) Future<List<String>>
listVersions(String table, {List<String>? namespace, String? branch}) Future<List<TableVersion>>
merge({required String table, required String on, required DatabaseRows records, List<String>? namespace, String? branch}) Future<void>
mergeStream({required String table, required String on, required DatabaseRowChunks chunks, List<String>? namespace, String? branch}) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
optimize({required String table, List<String>? namespace, String? branch}) Future<void>
restore({required String table, required int version, List<String>? namespace, String? branch}) Future<void>
searchStream({required String table, String? text, List<double>? vector, Object? where, int? offset, int? limit, List<String>? select, List<String>? namespace, String? branch, int? version}) DatabaseRowChunks
sql({required String query, required List<TableRef> tables, DatabaseRecord? params}) Future<DatabaseRows>
sqlStream({required String query, required List<TableRef> tables, DatabaseRecord? params}) DatabaseRowChunks
toString() String
A string representation of this object.
inherited
update({required String table, required String where, required DatabaseRecord values, List<String>? namespace, String? branch}) Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited