TableBranch class

Constructors

TableBranch({required String name, required String? parentBranch, required int? parentVersion, required DateTime? createdAt, required int? manifestSize})
const

Properties

createdAt DateTime?
final
hashCode int
The hash code for this object.
no setterinherited
manifestSize int?
final
name String
final
parentBranch String?
final
parentVersion int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) TableBranch