DatasetOptimizeConfig class

Constructors

DatasetOptimizeConfig({bool? compactFiles = true, bool? optimizeIndices = true, bool? cleanupOldVersions = false, int? targetRowsPerFragment, int? maxRowsPerGroup, int? maxBytesPerFile, bool? materializeDeletions, double? materializeDeletionsThreshold, bool? deferIndexRemap, int? numThreads, int? batchSize, String? compactionMode, int? binaryCopyReadBatchBytes, int? numIndicesToMerge, List<String>? indexNames, bool? retrain, double? olderThanSeconds = 604800, int? retainVersions, bool? deleteUnverified, bool? errorIfTaggedOldVersions, int? deleteRateLimit})
const

Properties

batchSize int?
final
binaryCopyReadBatchBytes int?
final
cleanupOldVersions bool?
final
compactFiles bool?
final
compactionMode String?
final
deferIndexRemap bool?
final
deleteRateLimit int?
final
deleteUnverified bool?
final
errorIfTaggedOldVersions bool?
final
hashCode int
The hash code for this object.
no setterinherited
indexNames List<String>?
final
materializeDeletions bool?
final
materializeDeletionsThreshold double?
final
maxBytesPerFile int?
final
maxRowsPerGroup int?
final
numIndicesToMerge int?
final
numThreads int?
final
olderThanSeconds double?
final
optimizeIndices bool?
final
retainVersions int?
final
retrain bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetRowsPerFragment int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited