DatasetOptimizeResult class

Constructors

DatasetOptimizeResult({Map<String, dynamic>? compaction, required bool optimizedIndices, Map<String, dynamic>? cleanup})
const

Properties

cleanup Map<String, dynamic>?
final
compaction Map<String, dynamic>?
final
hashCode int
The hash code for this object.
no setterinherited
optimizedIndices bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) DatasetOptimizeResult