DatasetStorageFormat enum

Inheritance
Available extensions

Values

auto → const DatasetStorageFormat
json → const DatasetStorageFormat
arrow → const DatasetStorageFormat
csv → const DatasetStorageFormat
tsv → const DatasetStorageFormat
parquet → const DatasetStorageFormat
excel → const DatasetStorageFormat

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String

Available on DatasetStorageFormat, provided by the DatasetStorageFormatValue extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<DatasetStorageFormat>
A constant List of the values in this enum, in order of their declaration.