DatasetTableWatchEvent class

Constructors

DatasetTableWatchEvent({required String kind, required DatasetTableWatchPhase phase, ArrowRecordBatch? batch, String? changeType, int? version, int? beginVersion, int? endVersion, List<Map<String, Object?>>? transactions, String? deletePredicate, Map<String, Object?>? transaction})
const

Properties

batch ArrowRecordBatch?
final
beginVersion int?
final
changeType String?
final
deletePredicate String?
final
endVersion int?
final
hashCode int
The hash code for this object.
no setterinherited
kind String
final
phase DatasetTableWatchPhase
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transaction Map<String, Object?>?
final
transactions List<Map<String, Object?>>?
final
version int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited