DatasetsClient class

Constructors

DatasetsClient({required RoomClient room})

Properties

hashCode int
The hash code for this object.
no setterinherited
room RoomClient
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addColumnsWithSchema({required String table, required ArrowSchema schema, List<String>? namespace, String? branch}) Future<void>
addColumnWithExpression({required String table, required Map<String, String> newColumns, List<String>? namespace, String? branch}) Future<void>
cancelSqlQuery({required String queryId}) Future<DatasetSqlCancelResult>
closeSqlQuery({required String queryId}) Future<void>
count({required String table, String? text, List<double>? vector, Object? where, List<String>? namespace, String? branch, int? version}) Future<int>
createBranch({required String branch, String? fromBranch, List<String>? namespace}) Future<void>
createIndex({required String table, required DatasetIndexConfig config, List<String>? namespace, String? branch}) Future<void>
createTableFromArrowBatches({required String name, required DatasetArrowBatches batches, CreateMode mode = CreateMode.create, List<String>? namespace, String? branch, Map<String, dynamic>? metadata}) Future<void>
createTableFromArrowTable({required String name, required ArrowTable table, CreateMode mode = CreateMode.create, List<String>? namespace, String? branch, Map<String, dynamic>? metadata}) Future<void>
createTableFromData({required String name, required DatasetRows data, CreateMode mode = CreateMode.create, List<String>? namespace, String? branch, Map<String, dynamic>? metadata}) Future<void>
createTableFromDataStream({required String name, required DatasetRowChunks chunks, CreateMode mode = CreateMode.create, List<String>? namespace, String? branch, Map<String, dynamic>? metadata}) Future<void>
createTableWithArrowSchema({required String name, required ArrowSchema schema, DatasetArrowBatches? batches, CreateMode mode = CreateMode.create, List<String>? namespace, String? branch, Map<String, dynamic>? metadata}) Future<void>
createTableWithSchema({required String name, required ArrowSchema schema, CreateMode mode = CreateMode.create, List<String>? namespace, String? branch, Map<String, dynamic>? metadata}) Future<void>
delete({required String table, required String where, List<String>? namespace, String? branch}) Future<void>
deleteBranch({required String branch, List<String>? namespace}) Future<void>
dropColumns({required String table, required List<String> columns, List<String>? namespace, String? branch}) Future<void>
dropIndex({required String table, required String name, List<String>? namespace, String? branch}) Future<void>
dropTable({required String name, bool ignoreMissing = false, List<String>? namespace, String? branch}) Future<void>
executeSql({required String query, List<TableRef>? tables, ArrowTable? params, List<String>? namespace, String? branch}) Future<DatasetSqlExecution>
executeSqlStatement({required String query, List<TableRef>? tables, ArrowTable? params, List<String>? namespace, String? branch}) Future<int>
exportToStorage({required String table, required String path, required DatasetStorageFormat format, List<String>? namespace, String? branch, int? version}) Future<void>
importFromStorage({required String table, required String path, DatasetImportMode mode = DatasetImportMode.create, DatasetStorageFormat format = DatasetStorageFormat.auto, String? on, String? sheet, int? batchSize, List<String>? namespace, String? branch}) Future<void>
insert({required String table, required ArrowRecordBatch records, List<String>? namespace, String? branch}) Future<void>
insertStream({required String table, required DatasetArrowBatches chunks, List<String>? namespace, String? branch}) Future<void>
insertTable({required String table, required ArrowTable records, List<String>? namespace, String? branch}) Future<void>
inspect(String table, {List<String>? namespace, String? branch, int? version}) Future<ArrowSchema>
listBranches({List<String>? namespace}) Future<List<TableBranch>>
listIndexes(String table, {List<String>? namespace, String? branch, int? version}) Future<List<TableIndex>>
listTables({List<String>? namespace, String? branch}) Future<List<String>>
listVersions(String table, {List<String>? namespace, String? branch}) Future<List<TableVersion>>
merge({required String table, required String on, required ArrowRecordBatch records, List<String>? namespace, String? branch}) Future<void>
mergeStream({required String table, required String on, required DatasetArrowBatches chunks, List<String>? namespace, String? branch}) Future<void>
mergeTable({required String table, required String on, required ArrowTable records, List<String>? namespace, String? branch}) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openSqlQuery({required String query, List<TableRef>? tables, ArrowTable? params, List<String>? namespace, String? branch}) Future<DatasetSqlQuery>
optimize({required String table, List<String>? namespace, String? branch, DatasetOptimizeConfig? config}) Future<DatasetOptimizeResult>
readSqlQuery({required String queryId}) DatasetArrowBatches
renameTable({required String name, required String newName, List<String>? namespace, String? branch}) Future<void>
restore({required String table, required int version, List<String>? namespace, String? branch}) Future<void>
searchStream({required String table, String? text, List<double>? vector, Object? where, int? offset, int? limit, List<String>? select, List<String>? namespace, String? branch, int? version}) DatasetArrowBatches
searchTable({required String table, String? text, List<double>? vector, Object? where, int? offset, int? limit, List<String>? select, List<String>? namespace, String? branch, int? version}) Future<ArrowTable>
sql({required String query, List<TableRef>? tables, ArrowTable? params, List<String>? namespace, String? branch}) Future<List<ArrowRecordBatch>>
sqlStream({required String query, List<TableRef>? tables, ArrowTable? params, List<String>? namespace, String? branch}) DatasetArrowBatches
sqlTable({required String query, List<TableRef>? tables, ArrowTable? params, List<String>? namespace, String? branch}) Future<ArrowTable>
stats(String table, {List<String>? namespace, String? branch, int? version, int? maxRowsPerGroup}) Future<DatasetTableStats>
toString() String
A string representation of this object.
inherited
update({required String table, required String where, required DatasetRecord values, List<String>? namespace, String? branch}) Future<void>
updateColumnMetadata({required String table, required String column, required Map<String, String> metadata, List<String>? namespace, String? branch}) Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited