ArrowArray class abstract base

Constructors

ArrowArray({required ArrowField field, required List<Object?> values})
factory

Properties

buffers List<ArrowBuffer>
no setter
field ArrowField
final
hashCode int
The hash code for this object.
no setterinherited
length int
final
name String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type ArrowDataType
no setter
values List<Object?>
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](int index) Object?