ArrowDecimalType class final

Inheritance

Constructors

ArrowDecimalType({required int bitWidth, required int precision, required int scale})
const

Properties

bitWidth int
final
hashCode int
The hash code for this object.
no setterinherited
precision int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scale int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited