ArrowIpcFileWriter class final
Constructors
-
ArrowIpcFileWriter({required ArrowSchema schema, required List<
ArrowRecordBatch> batches}) -
const
- ArrowIpcFileWriter.fromTable(ArrowTable table)
-
factory
Properties
-
batches
→ List<
ArrowRecordBatch> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schema → ArrowSchema
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
write(
) → Uint8List
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited