ArrowIpcSchema class final

Constructors

ArrowIpcSchema(Uint8List bytes)
const
ArrowIpcSchema.fromSchema(ArrowSchema schema)
factory

Properties

bytes Uint8List
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schema ArrowSchema
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited