ArrowListType class final
- Inheritance
-
- Object
- ArrowDataType
- ArrowListType
Constructors
- ArrowListType(ArrowField valueField, {bool large = false, bool view = false})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- large → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- valueField → ArrowField
-
final
- view → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited