ArrowMapArray class final

Inheritance

Constructors

ArrowMapArray({required ArrowField field, required ArrowListArray entries, required List<bool> validity})
const

Properties

buffers List<ArrowBuffer>
no setteroverride
entries ArrowListArray
final
field ArrowField
finalinherited
hashCode int
The hash code for this object.
no setterinherited
length int
finalinherited
name String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type ArrowDataType
no setterinherited
validity List<bool>
final
values List<Object?>
no setterinherited

Methods

entriesAt(int index) List<ArrowMapEntry>?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](int index) Object?
override