ArrowRecordBatch class final

Constructors

ArrowRecordBatch(Uint8List ipcBytes)
ArrowRecordBatch.fromColumns({required ArrowSchema schema, required List<ArrowArray> columns})

Properties

columns List<ArrowArray>
no setter
hashCode int
The hash code for this object.
no setterinherited
ipcBytes Uint8List
no setter
length int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schema ArrowSchema
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toRows() List<Map<String, Object?>>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited