ArrowSchema class final

Constructors

ArrowSchema(List<ArrowField> fields, {Map<String, String> metadata = const {}})
const

Properties

fields List<ArrowField>
final
hashCode int
The hash code for this object.
no setterinherited
metadata Map<String, String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited