ArrowTimestampType class final

Inheritance

Constructors

ArrowTimestampType({required ArrowTimeUnit unit, String? timezone})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timezone String?
final
unit ArrowTimeUnit
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited