ArrowTimestampValue class final

Constructors

ArrowTimestampValue({required ArrowTimeUnit unit, required int value, String? timezone})
const

Properties

dateTime DateTime
no setter
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timezone String?
final
unit ArrowTimeUnit
final
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override
toUnit(ArrowTimeUnit targetUnit) int

Operators

operator ==(Object other) bool
The equality operator.
override