DatabaseGrant class

Constructors

DatabaseGrant({List<TableGrant>? tables, bool listTables = true})
DatabaseGrant.fromJson(Map<String, dynamic> j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
listTables bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tables List<TableGrant>?
final

Methods

canAccess(String table, {List<String>? namespace}) bool
canAlter(String table, {List<String>? namespace}) bool
canRead(String table, {List<String>? namespace}) bool
canWrite(String table, {List<String>? namespace}) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited