LLMGrant class

Constructors

LLMGrant({List<String>? models})
LLMGrant.fromJson(Map<String, dynamic> j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
models List<String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

canUseModel({required String provider, required String model}) bool
canUseProvider(String provider) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited