MemoryEntryGrant class
Constructors
-
MemoryEntryGrant({required String name, List<
String> ? namespace, MemoryPermissions? permissions}) -
MemoryEntryGrant.fromJson(Map<
String, dynamic> j) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
final
-
namespace
→ List<
String> ? -
final
- permissions → MemoryPermissions
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited