MemoryGrant class

Constructors

MemoryGrant({bool list = true, List<MemoryEntryGrant>? memories})
MemoryGrant.fromJson(Map<String, dynamic> j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
list bool
final
memories List<MemoryEntryGrant>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

canAccessExisting(String name, {List<String>? namespace}) bool
canCreate(String name, {List<String>? namespace}) bool
canDrop(String name, {List<String>? namespace}) bool
canIngest(String name, {List<String>? namespace}) bool
canInspect(String name, {List<String>? namespace}) bool
canOptimize(String name, {List<String>? namespace}) bool
canQuery(String name, {List<String>? namespace}) bool
canRecall(String name, {List<String>? namespace}) bool
canUpsert(String name, {List<String>? namespace}) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited