SqliteGrant class

Constructors

SqliteGrant({List<SqliteDatabaseGrant>? databases, bool createDatabase = true, bool listDatabases = true})
SqliteGrant.fromJson(Map<String, dynamic> j)
factory

Properties

createDatabase bool
final
databases List<SqliteDatabaseGrant>?
final
hashCode int
The hash code for this object.
no setterinherited
listDatabases bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

canAlter(String database, String table, {List<String>? namespace}) bool
canCreateDatabase() bool
canCreateTable(String database, {List<String>? namespace}) bool
canDropDatabase(String database, {List<String>? namespace}) bool
canExecute(String database, {List<String>? namespace}) bool
canInspectDatabase(String database, {List<String>? namespace}) bool
canListDatabases() bool
canListTables(String database, {List<String>? namespace}) bool
canRead(String database, String table, {List<String>? namespace}) bool
canWrite(String database, String table, {List<String>? namespace}) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited