BinaryContent class

Inheritance

Constructors

BinaryContent({required Uint8List data, Map<String, dynamic>? headers})

Properties

data Uint8List
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, dynamic>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pack() Uint8List
Abstract pack method to be implemented by subclasses.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

unpack(Map<String, dynamic> header, Uint8List payload) BinaryContent