ContainerExitStatus class

Constructors

ContainerExitStatus({required int exitCode, String? reason, String? message, bool? oomKilled})

Properties

exitCode int
final
hashCode int
The hash code for this object.
no setterinherited
message String?
final
oomKilled bool?
final
reason String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) ContainerExitStatus