ContainerImage class

Lightweight image description (from containers.list_images)

Constructors

ContainerImage({required String id, required String? preferredRef, required List<String> references, required Map<String, String> labels, required DateTime? createdAt, required DateTime? updatedAt, required String? targetMediaType})
ContainerImage.fromJson(Map<String, dynamic> json)
factory

Properties

createdAt DateTime?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
labels Map<String, String>
final
preferredRef String?
final
references List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetMediaType String?
final
updatedAt DateTime?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited