ContainerImageDescriptor class

Constructors

ContainerImageDescriptor({required String digest, required String? mediaType, required int? size, required Map<String, String> annotations})
ContainerImageDescriptor.fromJson(Map<String, dynamic> json)
factory

Properties

annotations Map<String, String>
final
digest String
final
hashCode int
The hash code for this object.
no setterinherited
mediaType String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited