ContainerImageInspection class

Constructors

ContainerImageInspection({required ContainerImage image, required ContainerImageDescriptor target, required ContainerImageDescriptor? selectedManifest, required List<ContainerImageManifest> manifests, required ContainerImageDescriptor? config, required List<ContainerImageDescriptor> layers, required int? contentSize})
ContainerImageInspection.fromJson(Map<String, dynamic> json)
factory

Properties

config ContainerImageDescriptor?
final
contentSize int?
final
hashCode int
The hash code for this object.
no setterinherited
image ContainerImage
final
layers List<ContainerImageDescriptor>
final
manifests List<ContainerImageManifest>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedManifest ContainerImageDescriptor?
final
target ContainerImageDescriptor
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited