ContainerImageManifest class

Constructors

ContainerImageManifest({required ContainerImageDescriptor descriptor, required String? platformOs, required String? platformArchitecture, required String? platformVariant})
ContainerImageManifest.fromJson(Map<String, dynamic> json)
factory

Properties

descriptor ContainerImageDescriptor
final
hashCode int
The hash code for this object.
no setterinherited
platformArchitecture String?
final
platformOs String?
final
platformVariant String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited