ContainersClient class

Inheritance

Constructors

ContainersClient({required RoomClient room})

Properties

hashCode int
The hash code for this object.
no setterinherited
room RoomClient
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(void listener()) → void
inherited
build({required String tag, required List<ContainerMountSpec> mounts, required String contextPath, String? dockerfilePath, bool private = false, List<DockerSecret> credentials = const []}) Future<String>
deleteContainer({required String containerId}) Future<void>
deleteImage({required String image}) Future<void>
exec({required String containerId, required String command, bool tty = false, String? name}) ExecSession
list({bool? all}) Future<List<RoomContainer>>
listImages() Future<List<ContainerImage>>
loadImage({required List<ContainerMountSpec> mounts, required String archivePath, bool private = false}) Future<String>
logs({required String containerId, bool follow = false}) LogStream<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
inherited
pullImage({required String tag, List<DockerSecret> credentials = const []}) Future<void>
pushImage({required String tag, List<DockerSecret> credentials = const [], bool private = false}) Future<String>
removeListener(void listener()) → void
inherited
run({required String image, String? command, String? workingDir, Map<String, String> env = const {}, String? mountPath, String? mountSubpath, String? role, String? participantName, Map<int, int> ports = const {}, List<DockerSecret> credentials = const [], String? name, ContainerMountSpec? mounts, bool? writableRootFs, bool? private}) Future<String>
runService({required String serviceId, Map<String, String> env = const {}}) Future<String>
saveImage({required String tag, required List<ContainerMountSpec> mounts, required String archivePath, bool private = false}) Future<String>
stop({required String containerId, bool force = true}) Future<void>
toString() String
A string representation of this object.
inherited
waitForExit({required String containerId}) Future<int>

Operators

operator ==(Object other) bool
The equality operator.
inherited