EmailSpec class

Constructors

EmailSpec({required String address, bool public = false})
const

Properties

address String
final
hashCode int
The hash code for this object.
no setterinherited
public bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

formatWith(Map<String, String> values) EmailSpec
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) EmailSpec