ErrorContent class

Inheritance

Constructors

ErrorContent({required String text, int? code})

Properties

code int?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pack() Uint8List
Abstract pack method to be implemented by subclasses.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

unpack(Map<String, dynamic> header, Uint8List payload) ErrorContent