HeartbeatSpec class

Constructors

HeartbeatSpec({required String queue, String? threadId, List<AgentInputContent>? prompt, required int minutes})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
minutes int
final
prompt List<AgentInputContent>
final
queue String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
threadId String?
final

Methods

formatWith(Map<String, String> values) HeartbeatSpec
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) HeartbeatSpec