ListServicesResult class

Constructors

ListServicesResult({required List<ServiceSpec> services, required Map<String, ServiceRuntimeState> serviceStates})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
services List<ServiceSpec>
final
serviceStates Map<String, ServiceRuntimeState>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) ListServicesResult