MemoryIngestResult class

Constructors

MemoryIngestResult({required String name, required MemoryIngestStats stats, required List<String> entityIds})
MemoryIngestResult.fromJson(Map<String, dynamic> json, {String operation = "ingest_text"})
factory

Properties

entityIds List<String>
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stats MemoryIngestStats
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited