MemoryIngestStats class

Constructors

MemoryIngestStats({required int entities, required int relationships, required int sources})
MemoryIngestStats.fromJson(Map<String, dynamic> json)
factory

Properties

entities int
final
hashCode int
The hash code for this object.
no setterinherited
relationships int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sources int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited