MemoryRecallRelationship class
Constructors
Properties
- createdAt → String?
-
final
- description → String?
-
final
- expiredAt → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- invalidAt → String?
-
final
- relationshipType → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceEntityId → String
-
final
- targetEntityId → String
-
final
- validAt → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited