MemoryRelationshipRecord class
Constructors
-
MemoryRelationshipRecord({required String sourceEntityId, required String targetEntityId, String relationshipType = "RELATED_TO", String? description, double? confidence, String? createdAt, String? validAt, String? expiredAt, String? invalidAt, String? sourceEntityName, String? targetEntityName, Map<
String, String> ? metadata}) -
MemoryRelationshipRecord.fromJson(Map<
String, dynamic> json) -
factory
Properties
- confidence → double?
-
final
- createdAt → String?
-
final
- description → String?
-
final
- expiredAt → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- invalidAt → String?
-
final
-
metadata
→ Map<
String, String> ? -
final
- relationshipType → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceEntityId → String
-
final
- sourceEntityName → String?
-
final
- targetEntityId → String
-
final
- targetEntityName → String?
-
final
- validAt → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited