MessagingChannel class

Inheritance

Constructors

MessagingChannel({String protocol = 'meshagent.agent-message.v1', List<PromptTemplate>? prompts, Map<String, String>? annotations})
const

Properties

annotations Map<String, String>
finalinherited
hashCode int
The hash code for this object.
no setterinherited
prompts List<PromptTemplate>
final
protocol String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

formatWith(Map<String, String> values) MessagingChannel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) MessagingChannel