MessagingStream class

Properties

closed bool
no setter
events Stream<MessagingStreamEvent>
no setter
hashCode int
The hash code for this object.
no setterinherited
remoteParticipantId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
streamId String
final

Methods

close() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendMessage({required String type, required Map<String, dynamic> message, Uint8List? attachment}) Future<void>
sendMessageNowait({required String type, required Map<String, dynamic> message, Uint8List? attachment}) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited