MountedVolume class

Constructors

MountedVolume({required String id, required String name, required bool required, String description = '', Map<String, dynamic> metadata = const {}, Map<String, String> annotations = const {}, String storageClass = 'standard', int? maxSizeMb, List<MountedVolumeConsumer> consumers = const []})
const
MountedVolume.fromJson(Map<String, dynamic> json)
factory

Properties

annotations Map<String, String>
final
consumers List<MountedVolumeConsumer>
final
description String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
maxSizeMb int?
final
metadata Map<String, dynamic>
final
name String
final
required bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storageClass String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited