Participant class abstract

Inheritance
Implementers

Constructors

Participant({required RoomClient client, required String id})

Properties

client RoomClient
final
connections Iterable<String>
no setter
hashCode int
The hash code for this object.
no setterinherited
id String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(void listener()) → void
inherited
getAttribute(String name) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
inherited
removeListener(void listener()) → void
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited