PromptTemplate class

Constructors

PromptTemplate({required String name, String? description, required String prompt, Map<String, String>? annotations})

Properties

annotations Map<String, String>
final
description String?
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
prompt String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

formatWith(Map<String, String> values) PromptTemplate
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) PromptTemplate