QueueChannel class
- Inheritance
-
- Object
- ChannelSpec
- QueueChannel
Constructors
Properties
-
annotations
→ Map<
String, String> -
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
messageSchema
→ Map<
String, dynamic> ? -
final
- queue → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- threadingMode → String?
-
final
Methods
-
formatWith(
Map< String, String> values) → QueueChannel -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
Map< String, dynamic> json) → QueueChannel