RegistryReferencePage class

Constructors

RegistryReferencePage({required String repository, required List<RegistryReference> references, required String? nextLast})
RegistryReferencePage.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
nextLast String?
final
references List<RegistryReference>
final
repository String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited