RegistryTagPage class

Constructors

RegistryTagPage({required String repository, required List<String> tags, required List<RegistryTagVersion> versions, required String? nextLast})
RegistryTagPage.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
nextLast String?
final
repository String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List<String>
final
versions List<RegistryTagVersion>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited