RoomClient class

Inheritance

Constructors

RoomClient({required ProtocolFactory protocolFactory, Duration? reconnectTimeout, OAuthTokenRequestHandler? oauthTokenRequestHandler, SecretRequestHandler? secretRequestHandler})

Properties

agents AgentsClient
latefinal
apiGrant ApiScope?
no setter
closeKind ProtocolCloseKind?
no setter
closeReason String?
no setter
containers ContainersClient
latefinal
datasets DatasetsClient
latefinal
developer DeveloperClient
latefinal
events Stream<RoomEvent>
no setter
hashCode int
The hash code for this object.
no setterinherited
isClosed bool
no setter
isConnected bool
no setter
localParticipant LocalParticipant?
no setter
memory MemoryClient
latefinal
messaging MessagingClient
latefinal
participantToken ParticipantToken?
no setter
protocol RoomProtocolProxy
latefinal
queues QueuesClient
latefinal
ready Future<void>
no setter
roomName String?
no setter
roomUrl String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secrets SecretsClient
latefinal
services ServicesClient
latefinal
sessionId String?
no setter
storage StorageClient
latefinal
sync SyncClient
latefinal

Methods

addListener(void listener()) → void
inherited
call({required String name, required String url, required Map<String, dynamic> arguments}) Future<void>
dispose() → void
invoke({required String toolkit, required String tool, required ToolInput input, String? participantId, String? onBehalfOfId, Map<String, dynamic>? callerContext}) Future<ToolCallOutput>
invokeNowait({required String toolkit, required String tool, Content? input, String? participantId, String? onBehalfOfId, Map<String, dynamic>? callerContext}) → void
listen(void handler(RoomEvent event)) StreamSubscription<RoomEvent>
listToolkits({String? participantId, String? participantName, int? timeout}) Future<List<ToolkitDescription>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
inherited
removeListener(void listener()) → void
inherited
sendRequest(String type, Map<String, dynamic> request, {Uint8List? data}) Future<Content>
start({void onDone()?, void onError(Object? error)?}) Future<void>
toString() String
A string representation of this object.
inherited
waitForClose() Future<void>
waitUntilConnected() Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited