RoomContainer class

Constructors

RoomContainer({required String id, required String image, String? imageId, String? name, List<RoomContainerPort> ports = const [], required ParticipantInfo startedBy, required String state, required bool private, required String? serviceId, ContainerMountSpec? mounts, RoomContainerStats? stats, ContainerExitStatus? exitStatus})

Properties

exitStatus ContainerExitStatus?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
image String
final
imageId String?
final
mounts ContainerMountSpec?
final
name String?
final
ports List<RoomContainerPort>
final
private bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serviceId String?
final
startedBy ParticipantInfo
final
state String
final
stats RoomContainerStats?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) RoomContainer