RoomContainerStats class

Constructors

RoomContainerStats({int? cpuUsageNanoCores, int? memoryUsageBytes, int? memoryWorkingSetBytes, int? timestampNs})

Properties

cpuUsageNanoCores int?
final
hashCode int
The hash code for this object.
no setterinherited
memoryUsageBytes int?
final
memoryWorkingSetBytes int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestampNs int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) RoomContainerStats