ScheduledTaskSpec class

Constructors

ScheduledTaskSpec({String version = 'v1', String kind = 'ScheduledTask', ScheduledTaskMetadata? metadata, required String schedule, bool active = true, bool once = false, ScheduledTaskQueueSpec? queue, ContainerSpec? container})
ScheduledTaskSpec.fromYaml(String yaml)
factory

Properties

active bool
final
container ContainerSpec?
final
hashCode int
The hash code for this object.
no setterinherited
kind String
final
metadata ScheduledTaskMetadata
final
once bool
final
queue ScheduledTaskQueueSpec?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schedule String
final
version String
final

Methods

copyWith({ScheduledTaskMetadata? metadata, String? schedule, bool? active, bool? once, ScheduledTaskQueueSpec? queue, ContainerSpec? container}) ScheduledTaskSpec
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) ScheduledTaskSpec