ServicePortRuntimeState class

Constructors

ServicePortRuntimeState({required PortNum num, required String? liveness, required String livenessStatus, required double? lastCheckedAt, required String? lastError})

Properties

hashCode int
The hash code for this object.
no setterinherited
lastCheckedAt double?
final
lastError String?
final
liveness String?
final
livenessStatus String
final
num PortNum
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) ServicePortRuntimeState