ServiceRuntimeEvent class

Constructors

ServiceRuntimeEvent({required String type, required String reason, required String message, required int count, required double firstTimestamp, required double lastTimestamp})

Properties

count int
final
firstTimestamp double
final
firstTimestampTime DateTime
no setter
hashCode int
The hash code for this object.
no setterinherited
lastTimestamp double
final
lastTimestampTime DateTime
no setter
message String
final
reason String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) ServiceRuntimeEvent