ServiceSpec class

Constructors

ServiceSpec({Version version = Version.v1, required ServiceMetadata metadata, Kind kind = Kind.service, String? id, bool enabled = true, List<PortSpec>? ports, ContainerSpec? container, ExternalServiceSpec? external, List<AgentSpec>? agents})
ServiceSpec.fromYaml(String yaml)
factory

Properties

agents List<AgentSpec>
getter/setter pair
container ContainerSpec?
final
enabled bool
final
external ExternalServiceSpec?
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
kind Kind
final
metadata ServiceMetadata
final
ports List<PortSpec>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version Version
final

Methods

copyWith({Version? version, ServiceMetadata? metadata, Kind? kind, String? id, bool? enabled, List<PortSpec>? ports, List<AgentSpec>? agents, ContainerSpec? container, ExternalServiceSpec? external}) ServiceSpec
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) ServiceSpec