StorageClient class

Inheritance

Constructors

StorageClient({required RoomClient room})

Properties

hashCode int
The hash code for this object.
no setterinherited
room RoomClient
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(void listener()) → void
inherited
delete(String path, {bool? recursive = false}) Future<void>
download(String path) Future<FileContent>
downloadStream(String path, {int chunkSize = 64 * 1024}) Future<Stream<BinaryContent>>
downloadUrl(String path) Future<String>
exists(String path) Future<bool>
list(String path) Future<List<StorageEntry>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
inherited
removeListener(void listener()) → void
inherited
toString() String
A string representation of this object.
inherited
upload(String path, Uint8List bytes, {bool overwrite = false, String? name, String? mimeType}) Future<void>
uploadStream(String path, Stream<Uint8List> chunks, {bool overwrite = false, int chunkSize = 64 * 1024, int? size, String? name, String? mimeType}) Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited