UpdatedRegistryTag class

Constructors

UpdatedRegistryTag({required String repository, required String tag, required String digest, required bool deletedSource})
UpdatedRegistryTag.fromJson(Map<String, dynamic> json)
factory

Properties

deletedSource bool
final
digest String
final
hashCode int
The hash code for this object.
no setterinherited
repository String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited