SqliteDatabaseClient class

Constructors

SqliteDatabaseClient({required SqliteClient client, required String database, List<String>? namespace})

Properties

client SqliteClient
final
database String
final
hashCode int
The hash code for this object.
no setterinherited
namespace List<String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addColumnsWithSchema({required String table, required ArrowSchema schema}) Future<void>
count({required String table, Object? where, Object? params}) Future<int>
createDatabase({SqliteCreateMode mode = SqliteCreateMode.create}) Future<void>
createTableFromArrowBatches({required String name, required SqliteArrowBatches batches, SqliteCreateMode mode = SqliteCreateMode.create}) Future<void>
createTableFromArrowTable({required String name, required ArrowTable table, SqliteCreateMode mode = SqliteCreateMode.create}) Future<void>
createTableWithSchema({required String name, required ArrowSchema schema, SqliteArrowBatches? batches, SqliteCreateMode mode = SqliteCreateMode.create}) Future<void>
delete({required String table, required String where, Object? params}) Future<int>
dropColumns({required String table, required List<String> columns}) Future<void>
dropDatabase({bool ignoreMissing = false}) Future<void>
dropTable({required String name, bool ignoreMissing = false}) Future<void>
executeSql({required String query, Object? params}) Future<SqliteSqlExecution>
executeSqlStatement({required String query, Object? params}) Future<int>
insert({required String table, required ArrowRecordBatch records}) Future<void>
insertStream({required String table, required SqliteArrowBatches chunks}) Future<void>
insertTable({required String table, required ArrowTable records}) Future<void>
inspect(String table) Future<ArrowSchema>
inspectDatabase() Future<SqliteDatabaseDetails>
listTables() Future<List<String>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
renameTable({required String name, required String newName}) Future<void>
searchStream({required String table, Object? where, Object? params, int? offset, int? limit, List<String>? select}) SqliteArrowBatches
searchTable({required String table, Object? where, Object? params, int? offset, int? limit, List<String>? select}) Future<ArrowTable>
sql({required String query, Object? params}) Future<List<ArrowRecordBatch>>
sqlStream({required String query, Object? params}) SqliteArrowBatches
sqlTable({required String query, Object? params}) Future<ArrowTable>
toString() String
A string representation of this object.
inherited
update({required String table, required String where, required DatasetRecord values, Object? params}) Future<int>

Operators

operator ==(Object other) bool
The equality operator.
inherited