ExternalOAuthClientRegistration class
Constructors
- ExternalOAuthClientRegistration({required String id, required String delegatedTo, ConnectorRef? connector, OAuthClientConfig? oauth, required String clientId, String? clientSecret})
-
ExternalOAuthClientRegistration.fromJson(Map<
String, dynamic> json) -
factory
Properties
- clientId → String
-
final
- clientSecret → String?
-
final
- connector → ConnectorRef?
-
final
- delegatedTo → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- oauth → OAuthClientConfig?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited