FeedSubscription class

Constructors

FeedSubscription({required String id, required String feedId, required String projectId, required String room, required String? roomId, required String path, required DateTime createdAt, required Map<String, String> annotations})
FeedSubscription.fromJson(Map<String, dynamic> json)
factory

Properties

annotations Map<String, String>
final
createdAt DateTime
final
feedId String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
path String
final
projectId String
final
room String
final
roomId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited