LlmDelegation class
Constructors
-
LlmDelegation({required String id, required String token, required DateTime expiresAt, required String projectId, required AccessSubject delegator, required AccessSubject subject, required String maxBudget, List<
LlmProvider> ? providers, List<String> ? models}) -
const
-
LlmDelegation.fromJson(Map<
String, dynamic> json) -
factory
Properties
- delegator → AccessSubject
-
final
- expiresAt → DateTime
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- maxBudget → String
-
final
-
models
→ List<
String> ? -
final
- projectId → String
-
final
-
providers
→ List<
LlmProvider> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subject → AccessSubject
-
final
- token → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited