Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- admin → const String
- agentCreator → const String
- agentInventory → const String
- agentManager → const String
-
all
→ const List<
String> - apiKeyCreator → const String
- apiKeyInventory → const String
- apiKeyManager → const String
- billingManager → const String
- developer → const String
- feedCreator → const String
- feedInventory → const String
- feedManager → const String
- feedSubscriptionCreator → const String
- feedSubscriptionInventory → const String
- feedSubscriptionManager → const String
- groupManager → const String
- llmLoggerCreator → const String
- llmLoggerInventory → const String
- llmLoggerManager → const String
- llmProxyUser → const String
- mailboxCreator → const String
- mailboxInventory → const String
- mailboxManager → const String
- member → const String
- oauthClientCreator → const String
- oauthClientInventory → const String
- oauthClientManager → const String
- participantTokenCreator → const String
- repositoryCreator → const String
- repositoryInventory → const String
- repositoryManager → const String
- roomCreator → const String
- roomInventory → const String
- roomManager → const String
- routeCreator → const String
- routeInventory → const String
- routeManager → const String
- scheduledTaskCreator → const String
- scheduledTaskInventory → const String
- scheduledTaskManager → const String
- serviceAccountCreator → const String
- serviceAccountInventory → const String
- serviceAccountManager → const String
- serviceCreator → const String
- serviceInventory → const String
- serviceManager → const String
- sessionInventory → const String
- usageReporter → const String