RouteCorsRule class

Constructors

RouteCorsRule({required List<String> allowedOrigins, List<String> allowedMethods = const ['GET', 'HEAD'], List<String> allowedHeaders = const [], List<String> exposeHeaders = const [], int maxAgeSeconds = 3600, bool allowCredentials = false})
RouteCorsRule.fromJson(Map<String, dynamic> json)
factory

Properties

allowCredentials bool
final
allowedHeaders List<String>
final
allowedMethods List<String>
final
allowedOrigins List<String>
final
exposeHeaders List<String>
final
hashCode int
The hash code for this object.
no setterinherited
maxAgeSeconds int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited