RoutePath class

Constructors

RoutePath({String path = '/', String pathType = 'prefix', required Object targetPort})
RoutePath.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
path String
final
pathType String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetPort Object
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited