RouteSpec class
Constructors
-
RouteSpec({String version = 'v1', String kind = 'Route', required RouteMetadata metadata, required String domain, required RouteBackend backend, List<
RoutePath> paths = const []}) -
RouteSpec.fromJson(Map<
String, dynamic> json) -
factory
Properties
- backend → RouteBackend
-
final
- domain → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → String
-
final
- metadata → RouteMetadata
-
final
-
paths
→ List<
RoutePath> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- version → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited