Secret class
Constructors
-
Secret({required String id, required String projectId, String? ownerUserId, String? ownerServiceAccountId, String? createdByUserId, String? createdByServiceAccountId, required String type, required String name, required bool httpOnly, required Map<
String, dynamic> metadata, required Map<String, dynamic> annotations, String? currentVersionId, String? valueBase64, required DateTime createdAt, required DateTime updatedAt})
Properties
-
annotations
→ Map<
String, dynamic> -
final
- createdAt → DateTime
-
final
- createdByServiceAccountId → String?
-
final
- createdByUserId → String?
-
final
- currentVersionId → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- httpOnly → bool
-
final
- id → String
-
final
-
metadata
→ Map<
String, dynamic> -
final
- name → String
-
final
- ownerServiceAccountId → String?
-
final
- ownerUserId → String?
-
final
- projectId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
final
- updatedAt → DateTime
-
final
- valueBase64 → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited