ServiceAccount class

Constructors

ServiceAccount({required String id, required String projectId, required String key, required String name, String? displayName, String? email, String description = '', Map<String, dynamic> metadata = const {}, Map<String, String> annotations = const {}, DateTime? createdAt, DateTime? updatedAt, String? createdByUserId})
const
ServiceAccount.fromJson(Map<String, dynamic> json)
factory

Properties

annotations Map<String, String>
final
createdAt DateTime?
final
createdByUserId String?
final
description String
final
displayName String?
final
email String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
key String
final
metadata Map<String, dynamic>
final
name String
final
projectId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updatedAt DateTime?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited