StorageVolume class
Constructors
-
StorageVolume({required String id, required String roomId, required String name, required String subpath, required String description, required Map<
String, dynamic> metadata, required Map<String, String> annotations, required bool provisioned, required DateTime createdAt, required DateTime updatedAt, String storageClass = 'standard', int? maxSizeMb, String phase = 'pending', String? reconcileError}) -
const
-
StorageVolume.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
annotations
→ Map<
String, String> -
final
- createdAt → DateTime
-
final
- description → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- maxSizeMb → int?
-
final
-
metadata
→ Map<
String, dynamic> -
final
- name → String
-
final
- phase → String
-
final
- provisioned → bool
-
final
- reconcileError → String?
-
final
- roomId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storageClass → String
-
final
- subpath → String
-
final
- updatedAt → DateTime
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited