DatasetIndexConfig class
Constructors
-
DatasetIndexConfig({required Object column, required String indexType, String? name, String? metric, bool? replace, int? numPartitions, List<
List< ? ivfCentroids, List<double> >List< ? pqCodebook, int? numSubVectors, String? accelerator, int? indexCacheSize, int? shufflePartitionBatches, int? shufflePartitionConcurrency, String? ivfCentroidsFile, String? precomputedPartitionDataset, bool? filterNan, bool? train, List<double> >int> ? fragmentIds, String? indexUuid, int? targetPartitionSize, bool? skipTranspose, int? numBits, String? indexFileVersion, int? maxLevel, int? m, int? efConstruction, bool? withPosition, int? memoryLimit, int? numWorkers, bool? skipMerge, String? baseTokenizer, String? language, int? maxTokenLength, bool? lowerCase, bool? stem, bool? removeStopWords, List<String> ? customStopWords, bool? asciiFolding}) -
const
Properties
- accelerator → String?
-
final
- asciiFolding → bool?
-
final
- baseTokenizer → String?
-
final
- column → Object
-
final
-
customStopWords
→ List<
String> ? -
final
- efConstruction → int?
-
final
- filterNan → bool?
-
final
-
fragmentIds
→ List<
int> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- indexCacheSize → int?
-
final
- indexFileVersion → String?
-
final
- indexType → String
-
final
- indexUuid → String?
-
final
-
ivfCentroids
→ List<
List< ?double> > -
final
- ivfCentroidsFile → String?
-
final
- language → String?
-
final
- lowerCase → bool?
-
final
- m → int?
-
final
- maxLevel → int?
-
final
- maxTokenLength → int?
-
final
- memoryLimit → int?
-
final
- metric → String?
-
final
- name → String?
-
final
- numBits → int?
-
final
- numPartitions → int?
-
final
- numSubVectors → int?
-
final
- numWorkers → int?
-
final
-
pqCodebook
→ List<
List< ?double> > -
final
- precomputedPartitionDataset → String?
-
final
- removeStopWords → bool?
-
final
- replace → bool?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shufflePartitionBatches → int?
-
final
- shufflePartitionConcurrency → int?
-
final
- skipMerge → bool?
-
final
- skipTranspose → bool?
-
final
- stem → bool?
-
final
- targetPartitionSize → int?
-
final
- train → bool?
-
final
- withPosition → bool?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited