TableIndex class
Constructors
Properties
-
columns
→ List<
String> -
final
-
details
→ Map<
String, dynamic> -
final
-
fields
→ List<
int> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
final
- numRowsIndexed → int?
-
final
- numSegments → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
statistics
→ Map<
String, dynamic> -
final
- totalSizeBytes → int?
-
final
- type → String
-
final
- typeUrl → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
Map< String, dynamic> json) → TableIndex