ArrowField class final
Constructors
-
ArrowField({required String name, required ArrowDataType type, bool nullable = true, Map<
String, String> metadata = const {}}) -
const
Properties
- extensionMetadata → String?
-
no setter
- extensionName → String?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isExtension → bool
-
no setter
-
metadata
→ Map<
String, String> -
final
- name → String
-
final
- nullable → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → ArrowDataType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
withExtension(
{required String name, String extensionMetadata = ''}) → ArrowField
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited