ArrowListArray class final
- Inheritance
-
- Object
- ArrowArray
- ArrowListArray
Constructors
-
ArrowListArray({required ArrowField field, required List<
int> offsets, required List<int> sizes, required ArrowArray valuesArray, required List<bool> validity, List<ArrowBuffer> rawBuffers = const []}) -
const
Properties
-
buffers
→ List<
ArrowBuffer> -
no setteroverride
- field → ArrowField
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- length → int
-
finalinherited
- name → String
-
no setterinherited
-
offsets
→ List<
int> -
final
-
rawBuffers
→ List<
ArrowBuffer> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sizes
→ List<
int> -
final
- type → ArrowDataType
-
no setterinherited
-
validity
→ List<
bool> -
final
-
values
→ List<
Object?> -
no setterinherited
- valuesArray → ArrowArray
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
int index) → Object? -
override