ArrowRunEndEncodedArray class final
- Inheritance
-
- Object
- ArrowArray
- ArrowRunEndEncodedArray
Constructors
- ArrowRunEndEncodedArray({required ArrowField field, required ArrowArray runEnds, required ArrowArray runValues, required int length})
-
const
Properties
-
buffers
→ List<
ArrowBuffer> -
no setteroverride
- field → ArrowField
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- length → int
-
finalinherited
- name → String
-
no setterinherited
- runEnds → ArrowArray
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- runValues → ArrowArray
-
final
- type → ArrowDataType
-
no setterinherited
-
values
→ List<
Object?> -
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
int index) → Object? -
override