ArrowVariableBytesArray class final
- Inheritance
-
- Object
- ArrowArray
- ArrowVariableBytesArray
Constructors
- ArrowVariableBytesArray({required ArrowField field, required int length, required ArrowBuffer validityBuffer, required ArrowBuffer offsetsBuffer, required ArrowBuffer dataBuffer, required int nullCount, required bool large, required bool utf8Values})
-
const
Properties
-
buffers
→ List<
ArrowBuffer> -
no setteroverride
- dataBuffer → ArrowBuffer
-
final
- field → ArrowField
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- large → bool
-
final
- length → int
-
finalinherited
- name → String
-
no setterinherited
- nullCount → int
-
final
- offsetsBuffer → ArrowBuffer
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → ArrowDataType
-
no setterinherited
- utf8Values → bool
-
final
- validityBuffer → ArrowBuffer
-
final
-
values
→ List<
Object?> -
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
int index) → Object? -
override