MemoryPermissions class
Constructors
Properties
- create → bool
-
final
- drop → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- ingest → bool
-
final
- inspect → bool
-
final
- optimize → bool
-
final
- query → bool
-
final
- recall → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- upsert → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited