SqliteDatabaseGrant class
Constructors
-
SqliteDatabaseGrant({required String name, List<
String> ? namespace, bool createTable = true, bool drop = false, bool inspect = true, bool listTables = true, bool execute = true, List<SqliteTableGrant> ? tables}) -
SqliteDatabaseGrant.fromJson(Map<
String, dynamic> j) -
factory
Properties
- createTable → bool
-
final
- drop → bool
-
final
- execute → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inspect → bool
-
final
- listTables → bool
-
final
- name → String
-
final
-
namespace
→ List<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
tables
→ List<
SqliteTableGrant> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited