ChannelsSpec class
Constructors
-
ChannelsSpec({List<
EmailChannel> ? email, List<MessagingChannel> ? messaging, List<QueueChannel> ? queue, List<ToolkitChannel> ? toolkit}) -
const
Properties
-
email
→ List<
EmailChannel> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
messaging
→ List<
MessagingChannel> -
final
-
queue
→ List<
QueueChannel> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
toolkit
→ List<
ToolkitChannel> -
final
Methods
-
formatWith(
Map< String, String> values) → ChannelsSpec -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
Map< String, dynamic> json) → ChannelsSpec