MemoryClient class
Constructors
- MemoryClient({required RoomClient room})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- room → RoomClient
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
create(
{required String name, List< String> ? namespace, bool overwrite = false, bool ignoreExists = false}) → Future<void> -
drop(
{required String name, List< String> ? namespace, bool ignoreMissing = false}) → Future<void> -
list(
{List< String> ? namespace}) → Future<List< String> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited