MemoryRecallItem class
Constructors
-
MemoryRecallItem({required String entityId, required String name, required String entityType, String? context, double? confidence, String? createdAt, String? validAt, required double score, required List<
MemoryRecallRelationship> relationships}) -
MemoryRecallItem.fromJson(Map<
String, dynamic> json) -
factory
Properties
- confidence → double?
-
final
- context → String?
-
final
- createdAt → String?
-
final
- entityId → String
-
final
- entityType → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
final
-
relationships
→ List<
MemoryRecallRelationship> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- score → double
-
final
- validAt → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited