RoomProtocolProxy class
Constructors
- RoomProtocolProxy({required RoomClient room})
Properties
- closeKind → ProtocolCloseKind?
-
no setter
- closeReason → String?
-
no setter
-
done
→ Future<
Object?> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isClosed → bool
-
no setter
- isOpen → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- token → String?
-
no setter
- url → Uri?
-
no setter
Methods
-
addHandler(
String type, ProtocolMessageHandler handler) → void -
getHandler(
String type) → ProtocolMessageHandler? -
getNextMessageId(
) → int -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeHandler(
String type, ProtocolMessageHandler handler) → void -
send(
String type, Uint8List data, {int? id}) → Future< void> -
sendNowait(
String type, Uint8List data, {int? id}) → int -
toString(
) → String -
A string representation of this object.
inherited
-
waitForClose(
) → Future< void>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited