ServiceRuntimeState class
Constructors
Properties
- containerId → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastExitAt → double?
-
final
- lastExitAtTime → DateTime?
-
no setter
- lastExitCode → int?
-
final
- restartCount → int
-
final
- restartScheduledAt → double?
-
final
- restartScheduledAtTime → DateTime?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serviceId → String
-
final
- startedAt → double?
-
final
- startedAtTime → DateTime?
-
no setter
- state → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
Map< String, dynamic> json) → ServiceRuntimeState