ToolkitChannel class
- Inheritance
-
- Object
- ChannelSpec
- ToolkitChannel
Constructors
-
ToolkitChannel({required String name, Map<
String, String> ? annotations}) -
const
Properties
-
annotations
→ Map<
String, String> -
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
formatWith(
Map< String, String> values) → ToolkitChannel -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
Map< String, dynamic> json) → ToolkitChannel